Index: trunk/test/unit/org/openstreetmap/josm/tools/bugreport/BugReportExceptionHandlerTest.java
===================================================================
--- trunk/test/unit/org/openstreetmap/josm/tools/bugreport/BugReportExceptionHandlerTest.java	(revision 10062)
+++ trunk/test/unit/org/openstreetmap/josm/tools/bugreport/BugReportExceptionHandlerTest.java	(revision 10064)
@@ -2,9 +2,12 @@
 package org.openstreetmap.josm.tools.bugreport;
 
+import static org.junit.Assert.assertNotNull;
+
 import org.junit.Before;
+import org.junit.Test;
 import org.openstreetmap.josm.JOSMFixture;
 
 /**
  * Bug report unit tests.
  */
 public class BugReportExceptionHandlerTest {
@@ -17,3 +20,11 @@
         JOSMFixture.createUnitTestFixture().init();
     }
+
+    /**
+     * Unit test for {@link BugReportExceptionHandler#buildPanel} method.
+     */
+    @Test
+    public void testBuildPanel() {
+        assertNotNull(BugReportExceptionHandler.buildPanel(new Exception()));
+    }
 }
@@ -2,9 +2,12 @@
 
 /**
- * Bug report unit tests.
+ * Unit tests of {@link BugReportExceptionHandler} class.
  */
 public class BugReportExceptionHandlerTest {
